@@ -44,8 +44,8 @@ Authors: Soren Sandmann <sandmann@redhat.com>
 #include <cairo.h>
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
-#include <libmateui/mate-bg.h>
-#include <libmateui/mate-bg-crossfade.h>
+#include <mate-bg.h>
+#include <mate-bg-crossfade.h>
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 # include <cairo-xlib.h>
@@ -2639,14 +2639,14 @@ pixbuf_draw_gradient (GdkPixbuf    *pixbuf,
 	int height;
 	int rowstride;
 	guchar *dst;
-	guchar *dst_limit;
+	//guchar *dst_limit;
 	int n_channels = 3;
 
 	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
 	width = rect->width;
 	height = rect->height;
 	dst = gdk_pixbuf_get_pixels (pixbuf) + rect->x * n_channels + rowstride * rect->y;
-	dst_limit = dst + height * rowstride;
+	//dst_limit = dst + height * rowstride;
 
 	if (horizontal) {
 		guchar *gradient = create_gradient (primary, secondary, width);
