@@ -38,7 +38,7 @@
 #include <X11/Xatom.h>
 
 #undef MATE_DISABLE_DEPRECATED
-#include "libmateui/mate-rr.h"
+#include "mate-rr.h"
 
 #include "private.h"
 #include "mate-rr-private.h"
@@ -673,7 +673,11 @@ mate_rr_screen_new (GdkScreen *gdk_screen,
 	
 	screen->gdk_screen = gdk_screen;
 	screen->gdk_root = gdk_screen_get_root_window (gdk_screen);
+	#if GTK_CHECK_VERSION(3, 0, 0)
+	screen->xroot = gdk_x11_window_get_xid (screen->gdk_root);
+	#else
 	screen->xroot = gdk_x11_drawable_get_xid (screen->gdk_root);
+	#endif
 	screen->xdisplay = dpy;
 	screen->xscreen = gdk_x11_screen_get_xscreen (screen->gdk_screen);
 	screen->connector_type_atom = XInternAtom (dpy, "ConnectorType", FALSE);
